==> snf4j-example-1.2.0-sources.jar: org/snf4j/example/chat/ChatClientHandler.java <==
/*
 * -------------------------------- MIT License --------------------------------
 * 
 * Copyright (c) 2017 SNF4J contributors
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * -----------------------------------------------------------------------------
 */
package org.snf4j.example.chat;

import org.snf4j.core.EndingAction;
import org.snf4j.core.handler.AbstractStreamHandler;
import org.snf4j.core.handler.SessionEvent;
import org.snf4j.core.session.DefaultSessionConfig;
import org.snf4j.core.session.ISessionConfig;

public class ChatClientHandler extends AbstractStreamHandler {

	@Override
	public void read(byte[] data) {
		System.err.println(new String(data));
	}

	@Override
	public void event(SessionEvent event) {
		if (event == SessionEvent.CLOSED) {

			// Notify if the closing initiated by the server
			if (!getSession().getAttributes().containsKey(ChatClient.BYE_TYPED)) {
				System.err.println("Connection closed. Type \"bye\" to exit");
			}
		}
	}
	
	@Override
	public ISessionConfig getConfig() {
		
		// Gently stop the selector loop if session associated
		// with this handler ends
		return new DefaultSessionConfig()
				.setEndingAction(EndingAction.STOP);
	}

}

==> snf4j-example-1.5.0-sources.jar: org/snf4j/example/chat/ChatClientHandler.java <==
/*
 * -------------------------------- MIT License --------------------------------
 * 
 * Copyright (c) 2017-2020 SNF4J contributors
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * -----------------------------------------------------------------------------
 */
package org.snf4j.example.chat;

import org.snf4j.core.EndingAction;
import org.snf4j.core.handler.AbstractStreamHandler;
import org.snf4j.core.handler.SessionEvent;
import org.snf4j.core.session.DefaultSessionConfig;
import org.snf4j.core.session.ISessionConfig;

public class ChatClientHandler extends AbstractStreamHandler {

	@Override
	public void read(Object msg) {
		System.err.println(new String((byte[])msg));
	}

	@Override
	public void event(SessionEvent event) {
		if (event == SessionEvent.CLOSED) {

			// Notify if the closing initiated by the server
			if (!getSession().getAttributes().containsKey(ChatClient.BYE_TYPED)) {
				System.err.println("Connection closed. Type \"bye\" to exit");
			}
		}
	}
	
	@Override
	public ISessionConfig getConfig() {
		
		// Gently stop the selector loop if session associated
		// with this handler ends
		return new DefaultSessionConfig()
				.setEndingAction(EndingAction.STOP);
	}

}
